<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Artix
 */

?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="<?php echo esc_url( "https://gmpg.org/xfn/11" ); ?>">

	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<div id="page" class="site">
	<a class="skip-link screen-reader-text" href="#content"><?php /*esc_html_e( 'Skip to content', 'artix' ); */ ?></a>

	<header id="masthead" class="site-header">
		<div class="site-header-inner">
			<div class="site-branding">
				
					<?php
					the_custom_logo();
					if ( is_front_page() && is_home() ) :
						?>
						<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
						<?php
					else :
						?>
						<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
						<?php
					endif;
					$artix_description = get_bloginfo( 'description', 'display' );
					if ( $artix_description || is_customize_preview() ) :
						?>
						<p class="site-description">  <?php echo $artix_description; /* WPCS: xss ok. */ ?></p> 
					<?php endif; ?>
				
			</div><!-- .site-branding -->

			<nav id="site-navigation" class="main-navigation">
				<div class="menu-button-container"><button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false"><?php /*esc_html_e( 'Primary Menu', 'artix' );  */ ?><i class="fa fa-bars"></i></button></div>
				<?php
				wp_nav_menu( array(
					'theme_location' => 'menu-1',
					'menu_id'        => 'primary-menu',
					'container'      => '',
					'fallback_cb'    => 'false',
					'menu_class'     => 'menu sm sm-clean',
				) );
				?>
			</nav><!-- #site-navigation -->
		</div><!-- # site-header-inner -->
	
	</header><!-- #masthead -->
<?php if(is_front_page()) : ?>
	<div class="header-image">
		<div class="header-image-data">
			<div class="header-image-title">
				<h2><?php echo get_theme_mod('artix_header_image_title_text' , esc_html( 'Grab Your Audience and Expand' )); ?></h2>
			</div>
			<div class="header-image-subtitle">
				<p><?php echo get_theme_mod('artix_header_image_subtitle_text' , esc_html( 'Modern, Highly Customizable, Professional, Businessey!' )); ?></p>
			</div>
			<div class="header-image-link">
				<a href="#"><?php echo get_theme_mod('artix_cta_button_text' , esc_html( 'Let\'s Build!' )); ?></a>
			</div>
		</div>
	</div>
<?php endif; ?>
	<div id="content" class="site-content">
		<div class="site-content-inner">